#ifndef THEME_H
#define THEME_H

#define PNG ".png"

#define PIX_ROOT "/etc/hildon/theme/calendar/"

#define PIX_MONTH PIX_ROOT "calendar_month_normal" PNG
#define PIX_MONTH_CURRENT PIX_ROOT "calendar_month_current" PNG
#define PIX_MONTH_DIMMED PIX_ROOT "calendar_month_lastmonth" PNG
#define PIX_MONTH_PRESSED PIX_ROOT "calendar_month_pressed" PNG

#define PIX_MONTH_WEEK PIX_ROOT "calendar_month_week" PNG
#define PIX_MONTH_WEEK_PRESSED PIX_ROOT "calendar_month_week_pressed" PNG

#define PIX_WEEKDAY PIX_ROOT "calendar_weekday" PNG
#define PIX_WEEKDAY_CURRENT PIX_ROOT "calendar_weekday_current" PNG
#define PIX_WEEKDAY_PRESSED PIX_ROOT "calendar_weekday_pressed" PNG

#define PIX_WEEK_DAY_SHADE PIX_ROOT "calendar_week_day_shade" PNG
#define PIX_WEEK_DAY_SHADE_CURRENT PIX_ROOT "calendar_week_day_shade_current" PNG
#define PIX_WEEK_HOUR_LINE PIX_ROOT "calendar_week_hour_line" PNG
#define PIX_WEEK_TIME_COLUMN PIX_ROOT "calendar_week_time_column" PNG

#define PIX_GENERIC_PRESSED PIX_ROOT "generic_area_pressed" PNG

// NOTE: Manual preparation of emblems is required because of a bug in Qt
// (https://bugreports.qt-project.org/browse/QTBUG-17953).
#include <QPixmap>
namespace Theme
{
    extern QPixmap *TodoEmblem;
    extern QPixmap *BdayEmblem;
    void init();
}

#endif // THEME_H
